import { ReactNode } from "react"

export type TokenType =
  | "keyword"
  | "string"
  | "number"
  | "boolean"
  | "null"
  | "undefined"
  | "operator"
  | "punctuation"
  | "identifier"
  | "comment"
  | "regex"
  | "function"
  | "class"
  | "builtin"
  | "variable"
  | "property"
  | "decorator"
  | "whitespace"
  | "unknown"

export interface Token {
  type: TokenType
  content: string
}

export interface Theme {
  background: string
  text: string
  comment: string
  keyword: string
  string: string
  boolean: string
  null: string
  undefined: string
  function: string
  class: string
  builtin: string
  variable: string
  property: string
  decorator: string
  regex: string
  number: string
  operator: string
  punctuation: string
  identifier: string
  lineNumber: string
}

export type SupportedLanguage = "javascript" | "typescript" | "jsx" | "tsx"

export interface HighlighterProps {
  code: string
  language: SupportedLanguage
  showLineNumbers?: boolean
  wrapLines?: boolean
  maxHeight?: string
  isDarkMode?: boolean
  expandable?: boolean
  className?: string
  style?: React.CSSProperties
  customBackgroundColor?: string
  showCopyButton?: boolean
}

export interface ThemeContextType {
  theme: Theme
  setTheme: (theme: Theme) => void
  isDarkMode: boolean
  setIsDarkMode: (isDarkMode: boolean) => void
}

